==> makeen-expressionengine-0.0.51.tgz: package/src/utils/reflectionExtender.ts <==
import { Type } from "typescript";
import { dynamicObject } from "./dynamicObject";
import { getDirectProperty, setDirectProperty } from './general';
export class propertyInfo {
    propertyType(setValue: Object, propertyType: any) {
        throw new Error("Method not implemented.");
    }
    getIndexParameters(): propertyInfo {
        return new propertyInfo();
    }

    getValue(context: Object, arr: object[] | undefined = undefined): Object {
        if (arr == undefined) {
            if (typeof this.parameterType === "function") {
                return this.parameterType.call(this, context, context);
            }
            if (typeof context == 'string' || typeof context == 'number' || typeof context == 'boolean') {
                return (context as any)[this.name];
            }
            return getDirectProperty(context, this.name);
        }
        else {
            let result: Object = {};

            if (context instanceof dynamicObject) {
                for (let ar of arr) {
                    result = context.getItem(ar as unknown as string) as Object;
                }

            }
            return result;
        }
    }

    setValue(context: Object, setValue: Object) {
        setDirectProperty(context, this.name, setValue);
    }
    public parameterType: any;

    private _type: Type | undefined;
    public get type(): Type {
        return this._type as Type;
    }
    public set type(v: Type) {
        this._type = v;
    }

    private _name: string = "";
    public get name(): string {
        return this._name;
    }
    public set name(v: string) {
        this._name = v;
    }
}

export function getRuntimeProperties(proType: Type): propertyInfo[] {
    //console.log('Get runtime methods');
    let pros: propertyInfo[] = [];

    Object.getOwnPropertyNames(proType).forEach((element) => {
        let pro = new propertyInfo()
        pro.name = element;
        // Object.getOwnPropertyDescriptor()
        pros.push(pro);
    });
    return pros;
}

export function getType(val: any): Type {
    let data: Type = val;
    return data;
}

export function getGenericType<T>(instance: T): Type {
    if (instance instanceof String)
        return getType(instance as String)
    else if (instance instanceof Number)
        return getType(instance as Number)
    else if (instance instanceof Boolean)
        return getType(instance as Boolean)
    else
        return getType(instance as Object);
}

==> makeen-expressionengine-0.0.63.tgz: package/src/utils/reflectionExtender.ts <==
import { Type } from "typescript";
import { dynamicObject } from "./dynamicObject";
import { getDirectProperty, setDirectProperty } from './general';
export class propertyInfo {
    propertyType(setValue: Object, propertyType: any) {
        throw new Error("Method not implemented.");
    }
    getIndexParameters(): propertyInfo {
        return new propertyInfo();
    }

    getValue(context: Object, arr: object[] | undefined = undefined): Object {
        if (arr == undefined) {
            if (typeof this.parameterType === "function") {
                return this.parameterType.call(this, context, context);
            }
            if (typeof context == 'string' || typeof context == 'number' || typeof context == 'boolean') {
                return (context as any)[this.name];
            }
            return getDirectProperty(context, this.name);
        }
        else {
            let result: Object | undefined = undefined;

            if (context instanceof dynamicObject) {
                for (let ar of arr) {
                    result = context.getItem(ar as unknown as string) as Object;
                }

            }
            return result as Object;
        }
    }

    setValue(context: Object, setValue: Object) {
        setDirectProperty(context, this.name, setValue);
    }
     parameterType: any;

    private _type: Type | undefined;
     get type(): Type {
        return this._type as Type;
    }
     set type(v: Type) {
        this._type = v;
    }

    private _name: string = "";
     get name(): string {
        return this._name;
    }
     set name(v: string) {
        this._name = v;
    }
}

export function getRuntimeProperties(proType: Type): propertyInfo[] {
    //console.log('Get runtime methods');
    let pros: propertyInfo[] = [];

    Object.getOwnPropertyNames(proType).forEach((element) => {
        let pro = new propertyInfo()
        pro.name = element;
        // Object.getOwnPropertyDescriptor()
        pros.push(pro);
    });
    return pros;
}

export function getType(val: any): Type {
    let data: Type = val;
    return data;
}

export function getGenericType<T>(instance: T): Type {
    if (instance instanceof String)
        return getType(instance as String)
    else if (instance instanceof Number)
        return getType(instance as Number)
    else if (instance instanceof Boolean)
        return getType(instance as Boolean)
    else
        return getType(instance as Object);
}
